aboutsummaryrefslogtreecommitdiffstats
path: root/src/include/threads.h
diff options
context:
space:
mode:
authorgdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2008-11-08 10:58:59 +0000
committergdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2008-11-08 10:58:59 +0000
commit9336c1fc9fdae776126295737131d0a22b2f05b8 (patch)
tree4b49edb25b0478c4b82583a4f8241f0896094cc5 /src/include/threads.h
parent86acf7daf6a6f867964e7d736b21ee923ab66ebe (diff)
downloadChibiOS-9336c1fc9fdae776126295737131d0a22b2f05b8.tar.gz
ChibiOS-9336c1fc9fdae776126295737131d0a22b2f05b8.tar.bz2
ChibiOS-9336c1fc9fdae776126295737131d0a22b2f05b8.zip
git-svn-id: svn://svn.code.sf.net/p/chibios/svn/trunk@501 35acf78f-673a-0410-8e92-d51de3d6d3f4
Diffstat (limited to 'src/include/threads.h')
-rw-r--r--src/include/threads.h19
1 files changed, 12 insertions, 7 deletions
diff --git a/src/include/threads.h b/src/include/threads.h
index ba136ee85..a0b0b362b 100644
--- a/src/include/threads.h
+++ b/src/include/threads.h
@@ -127,17 +127,22 @@ struct Thread {
/** Thread state: Waiting on a mutex. */
#define PRWTMTX 4
/** Thread state: Waiting in \p chThdSleep() or \p chThdSleepUntil(). */
-#define PRSLEEP 5
+#define PRWTCOND 5
+/** Thread state: Waiting in \p chCondWait(). */
+#define PRSLEEP 6
/** Thread state: Waiting in \p chThdWait(). */
-#define PRWAIT 6
-/** Thread state: Waiting in \p chEvtWait(). */
-#define PRWTEVENT 7
+#define PRWAIT 7
+/** Thread state: Waiting in \p chEvtWaitOneTimeout() or
+ \p chEvtWaitAnyTimeout(). */
+#define PRWTOREVT 8
+/** Thread state: Waiting in \p chEvtWaitAllTimeout(). */
+#define PRWTANDEVT 9
/** Thread state: Waiting in \p chMsgSend(). */
-#define PRSNDMSG 8
+#define PRSNDMSG 10
/** Thread state: Waiting in \p chMsgWait(). */
-#define PRWTMSG 9
+#define PRWTMSG 11
/** Thread state: After termination.*/
-#define PREXIT 10
+#define PREXIT 12
/*
* Various flags into the thread p_flags field.